@@ -36,8 +36,14 @@ netread <- function(path = NULL,
                     i_elements = NULL,
                     j_elements = NULL) {
 
+
+# If `path` is `NULL`, set to simple blank character object
+if (is.null(path)) {
+  path <- ""
+}
+
   # CSV
-  if (filetype == "csv" | stringr::str_detect(path, "csv$")) {
+  if (filetype == "csv" | (!is.null(path) & stringr::str_detect(path, "csv$"))) {
 
     netread_csv(path = path,
                 nodelist = nodelist,
@@ -49,7 +55,7 @@ netread <- function(path = NULL,
                 net_name = net_name,
                 missing_code = missing_code)
 
-  } else if (filetype == "excel" | stringr::str_detect(path, "xls$") | stringr::str_detect(path, "xlsx$")) {
+  } else if (filetype == "excel" | (!is.null(path) & stringr::str_detect(path, "xls$")) | (!is.null(path) & stringr::str_detect(path, "xlsx$"))) {
 
     netread_excel(path = path,
                   nodelist = nodelist,
@@ -540,13 +546,25 @@ netread_excel <- function(path,
 netread_igraph <- function(object,
                            net_name = "network") {
 
+
   # Create output list
   output_list <- list()
 
+  # If nodes in igraph object don't have a name or ID vertex attribute,
+  # create one
+  if (is.null(igraph::V(object)$id)) {
+    igraph::V(object)$id <- 1:length(igraph::V(object))
+  }
+
+  if (is.null(igraph::V(object)$name)) {
+    igraph::V(object)$name <- igraph::V(object)$id
+  }
+
+
   igraph_extract <- igraph::as_data_frame(object, what = "both")
   edges <- igraph_extract$edges %>% dplyr::rename(i_elements = .data$from,
                                                   j_elements = .data$to)
-  nodes <- igraph_extract$vertices
+  nodes <- igraph_extract$vertices %>% dplyr::rename(node_id = .data$name)
 
   output_list$edgelist <- edges
   # assign(x = paste(net_name, "edgelist", sep = "_"), value = edges, envir = .GlobalEnv)
